starcluster.commands.runplugin

Package starcluster :: Package commands :: Module runplugin |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.commands.runplugin

     1  #!/usr/bin/env python
     2
     3  from base import CmdBase
     4
     5
     6 -class CmdRunPlugin(CmdBase):
     7      """
     8      runplugin <plugin_name> <cluster_tag>
     9
    10      Run a StarCluster plugin on a runnning cluster
    11
    12      plugin_name - name of plugin section defined in the config
    13      cluster_tag - tag name of a running StarCluster
    14
    15      Example:
    16
    17         $ starcluster runplugin myplugin mycluster
    18      """
    19      names = ['runplugin', 'rp']
    20
    21 -    def execute(self, args):
    22          if len(args) != 2:
    23              self.parser.error("Please provide a plugin_name and <cluster_tag>")
    24          plugin_name, cluster_tag = args
    25          self.cm.run_plugin(plugin_name, cluster_tag)
    26